@@ -1,20 +1,22 @@
-/*
-  Copyright (C) 2003-2006 Fons Adriaensen <fons.adriaensen@skynet.be>
-    
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU Lesser General Public License as published
-  by the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
+// ---------------------------------------------------------------------------------
+//
+//  Copyright (C) 2003-2008 Fons Adriaensen <fons@kokkinizita.net>
+//    
+//  This program is free software; you can redistribute it and/or modify
+//  it under the terms of the GNU Lesser General Public License as published
+//  by the Free Software Foundation; either version 2 of the License, or
+//  (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU Lesser General Public License for more details.
+//
+//  You should have received a copy of the GNU Lesser General Public
+//  License along with this program; if not, write to the Free Software
+//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//
+// ---------------------------------------------------------------------------------
 
 
 #ifndef __CLXCLIENT_H
@@ -30,6 +32,10 @@
 #include <clthreads.h>
 
 
+// -------------------------------------------------------------------------------------------
+
+const char *clxclient_version (void);
+
 // -------------------------------------------------------------------------------------------
 
 
@@ -56,7 +62,8 @@ public:
     int ysize (void) const { return HeightOfScreen (ScreenOfDisplay (_dpy, _dsn)); }
     int gray  (void) const { return 0; }
 
-    unsigned long  alloc_color (const char *name, unsigned long d);
+    unsigned long alloc_color (const char *name, unsigned long d);
+    unsigned long alloc_color (float r, float g, float b);
     XftColor *alloc_xftcolor (const char *name, XftColor *D);
     XftColor *alloc_xftcolor (float r, float g, float b, float a);
     void free_xftcolor (XftColor *C);
@@ -318,7 +325,8 @@ public:
     void setcolor (XftColor     *c) { _xft_color = c;  XSetForeground (_dpy, _gct, c->pixel); }
     void setfunc (int f) { XSetFunction (_dpy, _gct, f); }
     void setline (int d) { XSetLineAttributes (_dpy, _gct, d, LineSolid, CapButt, JoinBevel); } 
-  
+    void setline (int d, int m) { XSetLineAttributes (_dpy, _gct, d, m, CapButt, JoinBevel); } 
+    void setdash (char *v, int n, int i = 0) { XSetDashes (_dpy, _gct, i, v, n); }
     void move (int x, int y) { _xx = x; _yy = y; }
     void rmove (int x, int y) { _xx += x; _yy += y; }
     void draw (int x, int y) { XDrawLine (_dpy, _drw, _gct, _xx, _yy, x, y); _xx = x; _yy = y; }
@@ -336,6 +344,7 @@ public:
     void drawpoints (int n, XPoint *P);
     void drawlines (int n, XPoint *P);
     void drawsegments (int n, XSegment *S);
+    void putimage (XImage *I) { XPutImage (_dpy, _drw, _gct, I, 0, 0, _xx, _yy, I->width, I->height); }
     void clearwin (void) { XClearWindow (_dpy, _drw); }
 
     int  textwidth (const char *str);
@@ -395,7 +404,7 @@ class X_button_style
 {
 public:
 
-    enum { PLAIN = 0, BORDER = 1, RAISED = 2, LED = 0x100 };
+    enum { PLAIN = 0, BORDER = 1, RAISED = 2, ALEFT = 4, ARIGHT = 8 };
 
     XftFont *font;
     struct 
@@ -427,6 +436,7 @@ public:
     int  cbid (void) const { return _cbid; }
     int  stat (void) const { return _stat; } 
     void set_cbid (int cbid) { _cbid = cbid; }
+    void release (void);
     virtual void set_stat (int stat);
     virtual void redraw (void);
 
